{ config, lib, pkgs,  ... }:
{
    programs.firefox = {
        enable = true;
        package = pkgs.wrapFirefox pkgs.firefox-unwrapped {
            extraPolicies = {
                CaptivePortal = false;
                DisableFirefoxStudies = true;
                DisablePocket = true;
                DisableTelemetry = true;
                DisableFirefoxAccounts = false;
                NoDefaultBookmarks = true;
                OfferToSaveLogins = true;
                OfferToSaveLoginsDefault = true;
                PasswordManagerEnabled = true;
                FirefoxHome = {
                    Search = true;
                    Pocket = false;
                    Snippets = false;
                    TopSites = false;
                    Highlights = false;
                };
                UserMessaging = {
                    ExtensionRecommendations = false;
                    SkipOnboarding = true;
                };
            };
        };
        profiles = {
            alexandre = {
                id = 0;
                name = "alexandre";
                search = {
                    force = true;
                    default = "Google";
                    engines = {
                        "Nix Packages" = {
                            urls = [{
                                template = "https://search.nixos.org/packages";
                                params = [
                                    { name = "type"; value = "packages"; }
                                    { name = "query"; value = "{searchTerms}"; }
                                ];
                            }];
                            icon = "${pkgs.nixos-icons}/share/icons/hicolor/scalable/apps/nix-snowflake.svg";
                            definedAliases = [ "@np" ];
                        };
                        "NixOS Wiki" = {
                            urls = [{ template = "https://nixos.wiki/index.php?search={searchTerms}"; }];
                            iconUpdateURL = "https://nixos.wiki/favicon.png";
                            updateInterval = 24 * 60 * 60 * 1000;
                            definedAliases = [ "@nw" ];
                        };
                        "Wikipedia (en)".metaData.alias = "@wiki";
                        "Google".metaData.hidden = false;
                        "Amazon.com".metaData.hidden = true;
                        "Bing".metaData.hidden = true;
                        "eBay".metaData.hidden = true;
                    };
                };

              bookmarks = [
      	  {
      	    name = "wikipedia";
      	    tags = [ "wiki" ];
      	    keyword = "wiki";
      	    url = "https://en.wikipedia.org/wiki/Special:Search?search=%s&go=Go";
      	  }
      	  {
      	    name = "kernel.org";
      	    url ="https://v2.produhost.net/panel/16148/dashboard";
      	  }
      	  {
      	    name = "Nix sites";
      	    toolbar = true;
      	    bookmarks = [
      	      {
      	        name = "homepage";
      	        url = "https://nixos.org/";
      	      }
      	      {
      	        name = "wiki";
      	        tags = [ "wiki" "nix" ];
      	        url = "https://nixos.wiki/";
      	      }
      	    ];
      	  }
      	];
              settings = {
                   "general.smoothScroll" = true;
               };

                extraConfig = ''
                    user_pref("full-screen-api.ignore-widgets", true);
                    user_pref("media.ffmpeg.vaapi.enabled", true);
                    user_pref("media.rdd-vpx.enabled", true);
                '';
            };
        };
    };
}
