{ config, lib, pkgs, ... }:
let
  nur = import (builtins.fetchTarball "https://github.com/nix-community/NUR/archive/master.tar.gz") {
    inherit pkgs;
  };
in
{
  programs.firefox = {
    enable = true ;
    profiles.default = {
      isDefault = true ;
      extensions = lib.mkIf config.programs.firefox.enable
        (with nur.repos.rycee.firefox-addons; [
           french-dictionary
           i-dont-care-about-cookies
           ublock-origin
           privacy-badger
    	 keepassxc-browser
    	 clearurls
    	 decentraleyes
    	 floccus
         ]);
    search = {
      force = true;
      default = "Google";
      engines = {
        "Nix Packages" = {
           urls = [{
             template = "https://search.nixos.org/packages";
             params = [
               { name = "type"; value = "packages"; }
               { name = "query"; value = "{searchTerms}"; }
             ];
           }];
         icon = "${pkgs.nixos-icons}/share/icons/hicolor/scalable/apps/nix-snowflake.svg";
         definedAliases = [ "@np" ];
        };
        "NixOS Wiki" = {
           urls = [{ template = "https://nixos.wiki/index.php?search={searchTerms}"; }];
           iconUpdateURL = "https://nixos.wiki/favicon.png";
           updateInterval = 24 * 60 * 60 * 1000;
           definedAliases = [ "@nw" ];
         };
        "Wikipedia (en)".metaData.alias = "@wiki";
        "Google".metaData.hidden = false;
        "Amazon.com".metaData.hidden = true;
        "Bing".metaData.hidden = true;
        "eBay".metaData.hidden = true;
      };
    };
  
    bookmarks = [
      {
        name = "DRI";
	toolbar = true;
	bookmarks = [
          {
            name = "wiki";
            tags = [ "wiki" ];
            keyword = "wiki";
            url = "https://en.wikipedia.org/wiki/Special:Search?search=";
          }
          {
            name = "AVV";
            url ="https://v2.produhost.net/panel/16148/dashboard";
          }
	  {
	    name = "Alexandre";
	    url = "https://bbb.produhost.net/b/ale-1a8-984";
	  }
	  {
	    name = "David";
	    url = "https://bbb.produhost.net/b/dav-5aj-hxx";
	  }
	];
      }
    ];
  
    settings = {
      settings = {
        "browser.contentblocking.category" = "strict" ;
        "browser.search.region" = "CH" ;
        "browser.startup.homepage" = https://www.google.fr ;
	"browser.toolbars.bookmarks.visibility" = "always";
        "dom.security.https_only_mode" = true ;
        "dom.security.https_only_mode_ever_enabled" = true ;
        "extensions.blocklist.pingCountVersion" = -1 ;
        "extensions.databaseSchema" = 35 ;
        "extensions.ui.dictionary.hidden" = false ;
        "extensions.ui.extension.hidden" = false ;
        "extensions.ui.locale.hidden" = true ;
        "extensions.ui.sitepermission.hidden" = true ;
        "extensions.webcompat.enable_shims" = true ;
        "extensions.webcompat.perform_injections" = true ;
        "extensions.webcompat.perform_ua_overrides" = true ;
        "findbar.highlightAll" = true ;
        "font.name.serif.x-western" = "FreeSerif" ;
        "font.size.variable.x-western" = 20 ;
        "media.eme.enabled" = true ;
        "pref.browser.homepage.disable_button.current_page" = false ;
        "print_printer" = "Mozilla Save to PDF" ;
        "privacy.annotate_channels.strict_list.enabled" = true ;
        "privacy.clearOnShutdown.cookies" = true ;
        "privacy.clearOnShutdown.downloads" = false ;
        "privacy.clearOnShutdown.formdata" = false ;
        "privacy.clearOnShutdown.history" = false ;
        "privacy.clearOnShutdown.offlineApps" = true ;
        "privacy.clearOnShutdown.sessions" = false ;
        "privacy.donottrackheader.enabled" = true ;
        "privacy.firstparty.isolate" = true ;
        "privacy.history.custom" = true ;
        "privacy.purge_trackers.date_in_cookie_database" = 0 ;
        "privacy.trackingprotection.emailtracking.enabled" = true ;
        "privacy.trackingprotection.enabled" = true ;
        "privacy.trackingprotection.socialtracking.enabled" = true ;
      };
    };
    } ;
  } ;
}
